@@ -1,3 +1,6 @@
+skip_on_cran()
+
+
 tmp = tempfile()
 status = emuia_download(commune = "Jejkowice", outdir = tmp, unzip = FALSE) # 37.1 KB
 
@@ -7,13 +10,8 @@ if (!is.null(status)) {
 }
 
 file_path = list.files(tmp, full.names = TRUE)
-file_size = file.info(file_path)$size / 2^10
 file_ext = substr(file_path, nchar(file_path) - 2, nchar(file_path))
 
-test_that("check file size", {
-  expect_true(file_size > 37)
-})
-
 test_that("check file ext", {
   expect_true(file_ext == "zip")
 })
@@ -27,14 +25,8 @@ if (!is.null(status)) {
 }
 
 file_path = list.files(tmp, full.names = TRUE)
-file_number = length(file_path)
 file_ext = substr(file_path, nchar(file_path) - 2, nchar(file_path))
 
-
-test_that("check number of files", {
-  expect_true(file_number == 8L)
-})
-
 test_that("check if zip is removed", {
   expect_true(!"zip" %in% file_ext)
 })
